@@ -5,7 +5,6 @@ from robustify.result import (
     Ok,
     Result,
     UnwrapError,
-    assert_never,
     is_err,
     is_ok,
     returns,
@@ -21,7 +20,6 @@ __all__ = [
     "UnwrapError",
     "is_ok",
     "is_err",
-    "assert_never",
     "do",
     "isin",
     "MaxTriesReached",
